summaryrefslogtreecommitdiffstats
path: root/akregator/src/mk4storage/metakit/src/column.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/mk4storage/metakit/src/column.cpp')
-rw-r--r--akregator/src/mk4storage/metakit/src/column.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/akregator/src/mk4storage/metakit/src/column.cpp b/akregator/src/mk4storage/metakit/src/column.cpp
index 2d191c64..0873ac83 100644
--- a/akregator/src/mk4storage/metakit/src/column.cpp
+++ b/akregator/src/mk4storage/metakit/src/column.cpp
@@ -770,7 +770,7 @@ void c4_Column::StoreBytes(t4_i32 pos_, const c4_Bytes& buffer_)
t4_i32 c4_Column::PullValue(const t4_byte*& ptr_)
{
- t4_i32 mask = *ptr_ ? 0 : ~0;
+ t4_i32 tqmask = *ptr_ ? 0 : ~0;
t4_i32 v = 0;
for (;;) {
@@ -779,7 +779,7 @@ t4_i32 c4_Column::PullValue(const t4_byte*& ptr_)
break;
}
- return mask ^ (v - 0x80); // oops, last byte had bit 7 set
+ return tqmask ^ (v - 0x80); // oops, last byte had bit 7 set
}
void c4_Column::PushValue(t4_byte*& ptr_, t4_i32 v_)
@@ -1398,30 +1398,30 @@ void c4_ColOfInts::ResizeData(int index_, int count_, bool clear_)
/* _currwidth 1: 2: 4:
* shiftPos 3 2 1 shift the offset right this much
* maskPos 7 3 1 mask the offset with this
*/
const int shiftPos = _currWidth == 4 ? 1 : 4 - _currWidth;
- const int maskPos = (1 << shiftPos) - 1;
+ const int tqmaskPos = (1 << shiftPos) - 1;
// the following code is similar to c4_Column::Resize, but at bit level
// turn insertion into deletion by inserting entire bytes
if (count_ > 0) {
unsigned off = (unsigned) index_ >> shiftPos;
- int gapBytes = (count_ + maskPos) >> shiftPos;
+ int gapBytes = (count_ + tqmaskPos) >> shiftPos;
InsertData(off, gapBytes, clear_);
// oops, we might have inserted too low by a few entries
- const int bits = (index_ & maskPos) * _currWidth;
+ const int bits = (index_ & tqmaskPos) * _currWidth;
if (bits) {
- const int maskLow = (1 << bits) - 1;
+ const int tqmaskLow = (1 << bits) - 1;
// move the first few bits to start of inserted range
t4_byte* p = CopyNow(off + gapBytes);
- t4_byte one = *p & maskLow;
- *p &= ~maskLow;
+ t4_byte one = *p & tqmaskLow;
+ *p &= ~tqmaskLow;
* CopyNow(off) = one;
}
@@ -1398,30 +1398,30 @@ void c4_ColOfInts::ResizeData(int index_, int count_, bool clear_)
/* _currwidth 1: 2: 4:
* shiftPos 3 2 1 shift the offset right this much
- * maskPos 7 3 1 mask the offset with this
+ * tqmaskPos 7 3 1 tqmask the offset with this
*/
const int shiftPos = _currWidth == 4 ? 1 : 4 - _currWidth;